pub struct WebAuthnPrfUnlockOption {
pub encrypted_private_key: EncString,
pub encrypted_user_key: UnsignedSharedKey,
pub credential_id: Option<String>,
pub transports: Option<Vec<String>>,
}Expand description
The unlock data for a single WebAuthn PRF credential.
Fields
encrypted_private_key: EncStringThe private key of the unlock option, wrapped by the key derived from the credential’s PRF output
encrypted_user_key: UnsignedSharedKeyThe user key, encapsulated with the public key of the unlock option
credential_id: Option<String>Credential ID for this WebAuthn PRF credential.
transports: Option<Vec<String>>Transport methods available for this credential (e.g., “usb”, “nfc”, “ble”, “internal”, “hybrid”).